
<#Script to Upgrade VM Hardware Version on the target VM.

PowerShell Run Syntax in vCommander: Powershell.exe c:\scripts\commands\UpdateHwVer.ps1 #{target.deployedName} #{target.managedSystem.name}
****We Strongly Suggest having a VM backup before upgrading VM HW****
1. This will attempt to Shutdown the Guest OS if it's not already Powered off. 
2. It will check the current host of the vm to match VM Hw Version to Host
3. Sets New HW Version on the Target VM

Requirements:
Embotics Rest API
Vmware PowerCLi
Powershell V3 or higher
#>

#Input Parameters should not need to be changed
param (
      [Parameter(Mandatory=$True)]      
      [string]$TargetVM = $(Throw "Please provide target VM name "),
      [string]$VIServer = $(Throw "Please provide vCenter server name ")
      )

#Please Update the Cred File for your vCenter
    $vCredFile = 'c:\scripts\auth\cred.xml'   #< vCenter Encrypted Cred File must have access to all vmware management servers

############################################################################################################################

#Remove and re-add the modules    
        $moduleName = "VCommander"
        If (-not (Get-Module -name $moduleName)) {
                        Import-Module -Name $moduleName 
        } else {
                        Remove-Module $moduleName
                        Import-Module -Name $moduleName 
        }

#Connect to vCenter and Disable Cert warnings
        & "C:\Program Files (x86)\VMware\Infrastructure\vSphere PowerCLI\Scripts\Initialize-PowerCLIEnvironment.ps1"
        Set-PowerCLIConfiguration -InvalidCertificateAction ignore -Confirm:$False
        $cred = (New-DecryptCredential -keyFilePath $vCredFile) 
        Connect-VIServer -Server $VIServer -credential $cred
        Write-Host "Connected to $VIServer" 

## Add the VMware snapin so we can do stuff
        add-pssnapin VMware.VimAutomation.Core
  
## GetHost Version to Determine Virtual Hardware Verson Supported
        $CurrentHWVersion = (Get-vm -Name $TargetVM).Version
        $VMStatus = (Get-vm -Name $TargetVM).PowerState
        $CurrentHost = (Get-vm -Name $TargetVM).VMhost.name
        $VmHostVersion = (Get-vmhost -Name $CurrentHost).version
        $State = $VMStatus -eq "PoweredOff"
        If ($state -ne "True" )
            {
            Write-Host "Shutting Down $TargetVM" 
            Shutdown-VMGuest -VM $TargetVM -Confirm:$false 
            }
#Loop Test to see if VM state is powered off
        Write-Host "Check to See if VM state is "PoweredOff""
        Do {( $VMStatus = (Get-vm -Name $TargetVM).PowerState)
        Start-Sleep -seconds 5
        Write-host "LoopCheck"
        if ($VMStatus -eq "PoweredOff"){
          $Status="Shutdown"
        }
        }
        Until($Status -eq "Shutdown")
        Write-Host "VM Powered Off"

#Table Mapping Version to VMHwVersion
#Ref. http://kb.vmware.com/selfservice/microsites/search.do?language=en_US&cmd=displayKC&externalId=1003746

        If  ($vmhostVersion -like "4.*")
            {$vmHWVersion = "v7"}
        elseif ($vmhostVersion -like "5.0*")
            {$vmHWVersion = "v8"}
        elseif ($VmHostVersion -like "5.1*")
            {$vmHWVersion = "v9"}
        elseif ($VmHostVersion -like "5.5*")
            {$vmHWVersion = "v10"}
        elseif ($VmHostVersion -like "6.0*")
            {$vmHWVersion = "v11"}
         Else
            {Write-Host "Exiting with error: Could not match Hardware Version that Equals $VmHostVersion"
            Exit 1
            }

#Set the VM Version on the Machine
        Set-VM -VM $TargetVM -Version $vmHWVersion -Confirm:$false
        Write-host "New Virtual Machine Hardware Version is $vmHWVersion"
        Write-Host "Update Virtual Machine Hardware Script Completed"